@@ -67,6 +67,12 @@ else
     mid=""
 fi
 
+if test -f /etc/kernel/cmdline; then
+    cmdline="$(tr -s "$IFS" ' ' </etc/kernel/cmdline)"
+else
+    cmdline=""
+fi
+
 msg_stderr "# generate $tcsv"
 echo -ne '\xff\xfe' > "$tcsv"
 ukis="$(ls --sort=time --reverse $esp/EFI/Linux/*.efi)"
@@ -74,7 +80,7 @@ for uki in $ukis; do
     name="$(basename $uki .efi)"
     name="${name#${mid}-}"
     msg_stderr "#    add $name"
-    echo "shim${arch}.efi,$name,${uki#$esp} ,Comment"
+    echo "shim${arch}.efi,$name,${uki#$esp} ${cmdline},Comment"
 done \
     | tr '/' '\\' \
     | iconv -f utf-8 -t ucs-2le >> "$tcsv"
