@@ -3,7 +3,7 @@
 # SPDX-License-Identifier: GPL-2.0-only
 # (c) 2023 Gerd Hoffmann
 #
-""" inspect kek updates """
+""" inspect secure boot variable updates """
 import sys
 import struct
 import argparse
@@ -30,6 +30,7 @@ def wrap_pkcs7(data):
         # envelope is present
         return data
 
+    print('wrapping pkcs7 signature')
     ret = bytes([ 0x30, 0x82 ])
     ret += (len(data) + 15).to_bytes(length=2, byteorder='big')
     ret += wrap
@@ -40,7 +41,7 @@ def wrap_pkcs7(data):
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument('-u', '--update', dest = 'update', type = str,
-                        help = 'read kek update from FILE', metavar = 'FILE')
+                        help = 'read sb variable update from FILE', metavar = 'FILE')
     parser.add_argument('--pem', dest = 'pem',
                         action = 'store_true', default = False,
                         help = 'print certificates in PEM format')
