@@ -6,10 +6,10 @@ shim="$(echo /boot/efi/EFI/*/shim*.efi)"
 # run tests
 set -ex
 pe-dumpinfo --help
-pe-listsigs --help
+pe-inspect --help
 pe-addsigs --help
 for file in ${kernel} ${shim}; do
     if test -f "${file}"; then
-        pe-listsigs "${file}"
+        pe-inspect "${file}"
     fi
 done
