@@ -2,6 +2,7 @@ import os
 import json
 import argparse
 import unittest
+import tempfile
 import subprocess
 
 from virt.firmware.efi import certs
@@ -12,6 +13,7 @@ from virt.firmware.efi import devpath
 from virt.firmware.varstore import edk2
 from virt.firmware.varstore import linux
 from virt.firmware.varstore import aws
+from virt.firmware.varstore import authfiles
 
 from virt.firmware.bootcfg import linuxcfg
 from virt.firmware.bootcfg import main as bcfgmain
@@ -109,6 +111,15 @@ class TestsEdk2(unittest.TestCase):
         varlist.enable_secureboot()
         uefidata = aws.AwsVarStore.base64_varstore(varlist)
 
+    def test_authfiles(self):
+        varlist = efivar.EfiVarList()
+        varlist.enroll_platform_redhat()
+        varlist.add_microsoft_keys()
+        authdir = tempfile.TemporaryDirectory()
+        authfiles.AuthFilesVarStore.write_varstore(authdir.name, varlist);
+        vs = authfiles.AuthFilesVarStore(dirname = authdir.name)
+        authdir.cleanup()
+
     def test_parse_dbxupdate(self):
         with open(TEST_DBX, 'rb') as f:
             blob = f.read()
