@@ -189,7 +189,7 @@ class EfiVar:
     def parse_time(self, data, offset):
         """ parse struct EFI_TIME """
         (year, month, day, hour, minute, second, ns, tz, dl) = \
-            struct.unpack_from("=HBBBBBxLhBx", data, offset)
+            struct.unpack_from("<HBBBBBxLhBx", data, offset)
         if year:
             self.time = datetime.datetime(year, month, day,
                                           hour, minute, second,
@@ -201,7 +201,7 @@ class EfiVar:
     def parse_authdata(self, authdata):
         """ parse struct EFI_VARIABLE_AUTHENTICATION_2 """
         self.parse_time(authdata, 0)
-        (length, revision, certtype) = struct.unpack_from("=LHH", authdata, 16)
+        (length, revision, certtype) = struct.unpack_from("<LHH", authdata, 16)
         guid = guids.parse_bin(authdata, 24)
         if str(guid) != guids.EfiCertPkcs7:
             raise RuntimeError('no pkcs7 signature')
@@ -211,7 +211,7 @@ class EfiVar:
         """ generate struct EFI_TIME """
         if self.time is None:
             return b'\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0'
-        return struct.pack("=HBBBBBxLhBx",
+        return struct.pack("<HBBBBBxLhBx",
                            self.time.year, self.time.month, self.time.day,
                            self.time.hour, self.time.minute, self.time.second,
                            self.time.microsecond * 1000,
@@ -292,17 +292,17 @@ class EfiVar:
         self.update_time()
 
     def set_boot_next(self, index):
-        self.data = struct.pack('=H', index)
+        self.data = struct.pack('<H', index)
         self.update_time()
 
     def set_boot_order(self, order):
         self.data = b''
         for item in order:
-            self.data += struct.pack('=H', item)
+            self.data += struct.pack('<H', item)
         self.update_time()
 
     def append_boot_order(self, index):
-        self.data += struct.pack('=H', index)
+        self.data += struct.pack('<H', index)
         self.update_time()
 
     def set_from_file(self, filename):
@@ -327,9 +327,9 @@ class EfiVar:
     def fmt_boot_list(self):
         bootlist = []
         for pos in range(len(self.data) >> 1):
-            nr = struct.unpack_from('=H', self.data, pos * 2)
+            nr = struct.unpack_from('<H', self.data, pos * 2)
             bootlist.append(f'{nr[0]:04x}')
-            desc= ", ".join(bootlist)
+        desc = ", ".join(bootlist)
         return f'boot order: {desc}'
 
     def fmt_dev_path(self):
@@ -507,7 +507,9 @@ class EfiVarList(collections.UserDict):
             self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2011, False)
         if ms_db in ('uefi11', 'uefi23', 'uefi+rom23', 'all'):
             self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2023, False)
-        if ms_db in ('win+rom23', 'uefi+rom23'):
+        if ms_db in ('redhat', 'redhat+rom'):
+            self.add_cert('db', guids.MicrosoftVendor, certs.REDHAT_UEFI, False)
+        if ms_db in ('win+rom23', 'uefi+rom23', 'redhat+rom'):
             self.add_cert('db', guids.MicrosoftVendor, certs.MS_ROM_2023, False)
 
     def add_microsoft_kek_keys(self, ms_kek = 'all'):
